@@ -31,7 +31,10 @@ class Streamer(ConfigBase):
                     client_kwargs={'log_connection': False},
                     till_now=True
                 )
+                self._logger.info('Saving data to disk..')
+                self.client.redis_client.bgsave()
+                self._logger.info('Save complete!')
 
             # stream updates to the cache indefinitely
             self._logger.info(f'Starting streams...')
-            self.client.stream(routes=routes)
\ No newline at end of file
+            self.client.stream(routes=routes)
